@@ -1,8 +1,9 @@
 use ::axum::{
+    body::Body,
+    routing::{delete, get, post, put},
     extract::{self, FromRequest},
-    handler::{delete, get, post, put},
-    response::{self, IntoResponse},
-    routing::BoxRoute,
+    response::IntoResponse,
+    Json,
     Router,
 };
 use ajars_core::{HttpMethod, RestType};
@@ -14,7 +15,7 @@ pub mod axum {
 }
 
 pub trait AxumHandler<I: Serialize + DeserializeOwned, O: Serialize + DeserializeOwned, T, H> {
-    fn to(&self, handler: H) -> Router<BoxRoute>;
+    fn to(&self, handler: H) -> Router;
 }
 
 macro_rules! factory_tuple ({ $($param:ident)* } => {
@@ -25,26 +26,26 @@ macro_rules! factory_tuple ({ $($param:ident)* } => {
     R: Future<Output = Result<O, E>> + Send,
     E: IntoResponse + Send + 'static,
     H: 'static + Send + Sync + Clone + Fn(I, $($param,)*) -> R,
-    $( $param: FromRequest + Send + 'static, )*
+    $( $param: FromRequest<Body> + Send + 'static, )*
     {
-        fn to(&self, handler: H) -> Router<BoxRoute> {
+        fn to(&self, handler: H) -> Router {
             let route = match self.method() {
                 HttpMethod::DELETE => Router::new().route(self.path(), delete(
                     |payload: extract::Query<I>, $( $param: $param,)*| async move {
-                        (handler)(payload.0, $( $param,)*).await.map(response::Json)
-                })).boxed(),
+                        (handler)(payload.0, $( $param,)*).await.map(Json)
+                })),
                 HttpMethod::GET => Router::new().route(self.path(), get(
                     |payload: extract::Query<I>, $( $param: $param,)*| async move {
-                        (handler)(payload.0, $( $param,)*).await.map(response::Json)
-                    })).boxed(),
+                        (handler)(payload.0, $( $param,)*).await.map(Json)
+                    })),
                 HttpMethod::POST => Router::new().route(self.path(), post(
-                    |payload: extract::Json<I>, $( $param: $param,)*| async move {
-                        (handler)(payload.0, $( $param,)*).await.map(response::Json)
-                    })).boxed(),
+                    |payload: Json<I>, $( $param: $param,)*| async move {
+                        (handler)(payload.0, $( $param,)*).await.map(Json)
+                    })),
                 HttpMethod::PUT => Router::new().route(self.path(), put(
-                    |payload: extract::Json<I>, $( $param: $param,)*| async move {
-                        (handler)(payload.0, $( $param,)*).await.map(response::Json)
-                    })).boxed(),
+                    |payload: Json<I>, $( $param: $param,)*| async move {
+                        (handler)(payload.0, $( $param,)*).await.map(Json)
+                    })),
             };
 
             route
@@ -52,6 +53,40 @@ macro_rules! factory_tuple ({ $($param:ident)* } => {
     }
 });
 
+    //
+    // MODEL FN USED FOR CREATING THE MACRO
+    //
+    // impl <I: Serialize + DeserializeOwned + Send + 'static, O: Serialize + DeserializeOwned + Send + 'static, H, R, E, REST: RestType<I, O>, P> AxumHandler<I, O, P, H> 
+    // for REST
+    // where
+    // R: Future<Output = Result<O, E>> + Send,
+    // E: IntoResponse + Send + 'static,
+    // H: 'static + Send + Sync + Clone + Fn(I, String) -> R,
+    // P: FromRequest<Body> + Send + 'static, 
+    // {
+    //     fn to(&self, handler: H) -> Router {
+    //         let route = match self.method() {
+    //             HttpMethod::DELETE => Router::new().route(self.path(), delete(
+    //                 |payload: extract::Query<I>, p: P| async move {
+    //                     (handler)(payload.0, p).await.map(Json)
+    //             })),
+    //             HttpMethod::GET => Router::new().route(self.path(), get(
+    //                 |payload: extract::Query<I>, p: P| async move {
+    //                     (handler)(payload.0, p).await.map(Json)
+    //                 })),
+    //             HttpMethod::POST => Router::new().route(self.path(), post(
+    //                 |payload: Json<I>, p: P| async move {
+    //                     (handler)(payload.0, p).await.map(Json)
+    //                 })),
+    //             HttpMethod::PUT => Router::new().route(self.path(), put(
+    //                 |payload: Json<I>, p: P| async move {
+    //                     (handler)(payload.0, p).await.map(Json)
+    //                 })),
+    //         };
+    //         route
+    //     }
+    // }
+
 factory_tuple! {}
 factory_tuple! { P0 }
 factory_tuple! { P0 P1 }
@@ -72,7 +107,7 @@ mod tests {
 
     use super::*;
     use ::axum::{
-        body::Body,
+        body::{Body, BoxBody},
         extract::Extension,
         http::{header, Method, Request, Response, StatusCode},
         AddExtensionLayer,
@@ -105,16 +140,14 @@ mod tests {
     }
 
     impl IntoResponse for ServerError {
-        type Body = axum::body::Body;
-        type BodyError = <Self::Body as axum::body::HttpBody>::Error;
-
-        fn into_response(self) -> Response<Self::Body> {
-            Response::new(Body::empty())
+        fn into_response(self) -> Response<BoxBody> {
+            Response::new(axum::body::boxed(Body::empty()))
         }
     }
 
     #[tokio::test]
     async fn should_create_a_delete_endpoint() {
+
         // Arrange
         let rest =
             RestFluent::<PingRequest, PingResponse>::delete(format!("/api/something/{}", rand::random::<usize>()));
@@ -275,4 +308,5 @@ mod tests {
             Result::<_, ServerError>::Ok(PingResponse { message: body.message })
         });
     }
+
 }
